/*
 * Name:    example1a.c
 *
 * Purpose: This program demonstrates how to initialize MX
 *          using a database file.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2006 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_driver.h"

int
main( int argc, char *argv[] )
{
        MX_RECORD *mx_database, *area_detector_record;
        char mx_database_name[] = "./mx_client.dat";
        char area_detector_name[] = "ad";
        mx_status_type mx_status;

        mx_status = mx_setup_database( &mx_database, mx_database_name );

        if ( mx_status.code != MXE_SUCCESS ) {
            fprintf( stderr, "Did not successfully open MX database '%s'.\n",
                mx_database_name );
            exit(1);
        }

        area_detector_record = mx_get_record( mx_database, area_detector_name );

        if ( area_detector_record == NULL ) {
            fprintf( stderr, "Did not find record '%s' in MX database '%s'.\n",
                area_detector_name, mx_database_name );
            exit(1);
        }

        if ( area_detector_record->mx_type != MXT_AD_NETWORK ) {
            fprintf( stderr,
                "MX record '%s' is not a network area detector record.\n",
                    area_detector_record->name );
            fprintf( stderr, "Instead, it is of type '%s'.\n",
                    mx_get_driver_name( area_detector_record ) );
            exit(1);
        }

        printf( "Successfully found network area detector '%s'.\n",
            area_detector_record->name );

        exit(0);
}
