/*
 * Name:    example1b.c
 *
 * Purpose: This program demonstrates how to initialize MX
 *          using a database stored in an array.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2006 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_driver.h"

#define NUM_RECORDS 2
#define LINE_LENGTH 80

int
main( int argc, char *argv[] )
{
        MX_RECORD *mx_database, *area_detector_record;
        char server_host[] = "192.168.137.3";
        long server_port = 9827;
        char area_detector_name[] = "ad";
        char **db_array;
        mx_status_type mx_status;

        db_array = malloc( 2 * sizeof(char *) );

        if ( db_array == NULL ) {
            fprintf( stderr,
                "Could not allocate row pointer for db_array.\n" );
            exit(1);
        }

        db_array[0] = malloc( LINE_LENGTH * sizeof(char) );

        if ( db_array[0] == NULL ) {
            fprintf( stderr,
                "Could not allocate row 0 of db_array.\n" );
            exit(1);
        }

        db_array[1] = malloc( LINE_LENGTH * sizeof(char) );

        if ( db_array[1] == NULL ) {
            fprintf( stderr,
                "Could not allocate row 1 of db_array.\n" );
            exit(1);
        }

        snprintf( db_array[0], LINE_LENGTH,
            "adserver server network tcp_server \"\" \"\" 0x0 %s %ld",
                 server_host, server_port );

        snprintf( db_array[1], LINE_LENGTH,
        "%s device area_detector network_area_detector \"\" \"\" 8 adserver ad",
            area_detector_name );

        mx_status = mx_setup_database_from_array( &mx_database,
                                                NUM_RECORDS, db_array );

        if ( mx_status.code != MXE_SUCCESS ) {
            fprintf( stderr, "Did not successfully open MX database array.\n");
            exit(1);
        }

        area_detector_record = mx_get_record( mx_database, area_detector_name );

        if ( area_detector_record == NULL ) {
            fprintf( stderr, "Did not find record '%s' in the MX database.\n",
                area_detector_name );
            exit(1);
        }

        if ( area_detector_record->mx_type != MXT_AD_NETWORK ) {
            fprintf( stderr,
                "MX record '%s' is not a network area detector record.\n",
                    area_detector_record->name );
            fprintf( stderr, "Instead, it is of type '%s'.\n",
                    mx_get_driver_name( area_detector_record ) );
            exit(1);
        }

        printf( "Successfully found network area detector '%s'.\n",
            area_detector_record->name );

        exit(0);
}
